<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'yes' => 'Ano',
    'no' => 'Ne',
    'update' => 'Aktualizovat',
    'save' => 'Uložit',
    'add' => 'Přidat',
    'cancel' => 'Zrušit',
    'confirm' => 'Potvrdit',
    'delete_confirm' => 'Jste si jisti?',
    'delete' => 'Smazat',
    'edit' => 'Upravit',
    'upload' => 'Nahrát',
    'download' => 'Stáhnout',
    'save_close' => 'Uložit a zavřít',
    'close' => 'Zavřít',
    'copy' => 'Kopírovat',
    'create' => 'Vytvořit',
    'remove' => 'Odstranit',
    'revoke' => 'Odvolat',
    'done' => 'Hotovo',
    'back' => 'Zpět',
    'verify' => 'Ověřit',
    'new' => 'nový',
    'unknown' => 'Nevím',
    'load_more' => 'Načíst další',
    'loading' => 'Načítání…',
    'with' => 's',
    'today' => 'dnes',
    'yesterday' => 'včera',
    'another_day' => 'jiný den',
    'date' => 'Datum',
    'type' => 'Typ',
    'zoom' => 'Zvětšení',
    'upgrade' => 'Upgradujte pro odemknutí',
    'percent_uploaded' => '{percent}% nahráno',
    'retry' => 'Opakovat',
    'filter' => 'Filtrovat seznam',
    'go_back' => 'Jít zpět',
    'file_selected' => 'Jeden soubor vybrán…| vybráno {count} souborů…',

    'application_title' => 'Monica – správce osobních vztahů',
    'application_description' => 'Monica is a tool to manage your interactions with your loved ones, friends and family.',
    'application_og_title' => 'Pro lepší vztahy s vašimi blízkými. Bezplatný online CRM pro přátele a rodinu.',

    'markdown_description' => 'Chcete pohodlně formátovat text? Podporujeme formát markdown pro značení tučně, kurzivou, vytváření seznamu a další.',
    'markdown_link' => 'Číst dokumentaci',

    'header_settings_link' => 'Nastavení',
    'header_logout_link' => 'Odhlásit',
    'header_changelog_link' => 'Změny produktu',

    'main_nav_cta' => 'Přidat osobu',
    'main_nav_dashboard' => 'Nástěnka',
    'main_nav_family' => 'Kontakty',
    'main_nav_journal' => 'Deník',
    'main_nav_activities' => 'Aktivity',
    'main_nav_tasks' => 'Úkoly',

    'footer_remarks' => 'Komentáře?',
    'footer_send_email' => 'Pošlete nám e-mail',
    'footer_privacy' => 'Podmínky používání',
    'footer_release' => 'Poznámky k vydání',
    'footer_newsletter' => 'Odběr novinek',
    'footer_source_code' => 'Monica na GitHubu',
    'footer_version' => 'Verze: :version',
    'footer_new_version' => 'Je dostupné nová verze aplikace Monica',

    'footer_modal_version_whats_new' => 'Novinky',
    'footer_modal_version_release_away' => 'Jste jedno vydání pozadu za nejnovější dostupnou verzí. Měli byste aktualizovat svou instanci.|Jste :number vydání pozadu za nejnovější dostupnou verzí. Měli byste aktualizovat svou instanci.',

    'breadcrumb_dashboard' => 'Nástěnka',
    'breadcrumb_list_contacts' => 'Seznam kontaktů',
    'breadcrumb_archived_contacts' => 'Archivované kontakty',
    'breadcrumb_journal' => 'Deník',
    'breadcrumb_settings' => 'Nastavení',
    'breadcrumb_settings_export' => 'Export',
    'breadcrumb_settings_users' => 'Uživatelé',
    'breadcrumb_settings_users_add' => 'Přidat uživatele',
    'breadcrumb_settings_subscriptions' => 'Odběry',
    'breadcrumb_settings_import' => 'Import',
    'breadcrumb_settings_import_report' => 'Importovat report',
    'breadcrumb_settings_import_upload' => 'Nahrát',
    'breadcrumb_settings_tags' => 'Tagy',
    'breadcrumb_add_significant_other' => 'Přidat drahou polovičku',
    'breadcrumb_edit_significant_other' => 'Upravit drahou polovičku',
    'breadcrumb_add_note' => 'Přidat poznámku',
    'breadcrumb_edit_note' => 'Upravit poznámku',
    'breadcrumb_api' => 'API',
    'breadcrumb_dav' => 'DAV zdroje',
    'breadcrumb_edit_introductions' => 'Jak jste se setkali',
    'breadcrumb_settings_personalization' => 'Přizpůsobení',
    'breadcrumb_settings_security' => 'Zabezpečení',
    'breadcrumb_settings_security_2fa' => 'Dvoufázové ověření',
    'breadcrumb_profile' => 'Profil :name',

    'gender_male' => 'Muž',
    'gender_female' => 'Žena',
    'gender_none' => 'Nepovím',
    'gender_no_gender' => 'Žádné pohlaví',

    'error_title' => 'Jejda! Něco se pokazilo.',
    'error_unauthorized' => 'Nemáte právo upravovat tento zdroj.',
    'error_user_account' => 'Tento uživatel nepatří k danému účtu.',
    'error_save' => 'Došlo k chybě při ukládání dat.',
    'error_try_again' => 'Něco se pokazilo. Zkuste to znovu.',
    'error_id' => 'ID chyby: :id',
    'error_unavailable' => 'Služba není dostupná',
    'error_maintenance' => 'Probíhá údržba. Budeme obratem zpátky.',
    'error_help' => 'Budeme hned zpátky.',
    'error_twitter' => 'Sledujte <a href="https://twitter.com/:twitter">náš Twitter účet</a> a buďte upozorněni, až služba znovu poběží.',
    'error_no_term' => 'Pro tuto instanci zatím neexistují žádná pravidla.',

    'default_save_success' => 'Data byla uložena.',

    'compliance_title' => 'Omlouváme se za vyrušení.',
    'compliance_desc' => 'Změnili jsme <a href=":urlterm" hreflang=":hreflang">Smluvní podmínky</a> a <a href=":url" hreflang=":hreflang">Zásady ochrany osobních údajů</a>. Podle zákona vás musíme požádat, abyste je zkontrolovali a přijali, abyste mohli nadále používat svůj účet.',
    'compliance_desc_end' => 'We don’t do anything nasty with your data or account and will never do.',
    'compliance_terms' => 'Přijmout nové podmínky a zásady ochrany osobních údajů',

    // Relationship types
    // Yes, each relationship type has 8 strings associated with it.
    // This is because we need to indicate the name of the relationship type,
    // and also the name of the opposite side of this relationship (father/son),
    // and then, the feminine version of the string. Finally, in some sentences
    // in the UI, we need to include the name of the person we add the relationship
    // to.
    'relationship_type_group_love' => 'Milostné vztahy',
    'relationship_type_group_family' => 'Rodinné vztahy',
    'relationship_type_group_friend' => 'Vztahy s přáteli',
    'relationship_type_group_work' => 'Pracovní vztahy',
    'relationship_type_group_other' => 'Jiný druh vztahů',

    'relationship_type_partner' => 'drahá polovička',
    'relationship_type_partner_female' => 'drahá polovička',
    'relationship_type_partner_male' => 'drahá polovička',
    'relationship_type_partner_with_name' => ':name’s significant other',
    'relationship_type_partner_female_with_name' => ':name’s significant other',
    'relationship_type_partner_male_with_name' => ':name’s significant other',

    'relationship_type_spouse' => 'Manžel(ka)',
    'relationship_type_spouse_female' => 'manželka',
    'relationship_type_spouse_male' => 'manžel',
    'relationship_type_spouse_with_name' => ':name’s spouse',
    'relationship_type_spouse_female_with_name' => ':name’s wife',
    'relationship_type_spouse_male_with_name' => ':name’s husband',

    'relationship_type_date' => 'date',
    'relationship_type_date_female' => 'date',
    'relationship_type_date_male' => 'date',
    'relationship_type_date_with_name' => ':name’s date',
    'relationship_type_date_female_with_name' => ':name’s date',
    'relationship_type_date_male_with_name' => ':name’s date',

    'relationship_type_lover' => 'lover',
    'relationship_type_lover_female' => 'lover',
    'relationship_type_lover_male' => 'lover',
    'relationship_type_lover_with_name' => ':name’s lover',
    'relationship_type_lover_female_with_name' => ':name’s lover',
    'relationship_type_lover_male_with_name' => ':name’s lover',

    'relationship_type_inlovewith' => 'in love with',
    'relationship_type_inlovewith_female' => 'in love with',
    'relationship_type_inlovewith_male' => 'in love with',
    'relationship_type_inlovewith_with_name' => 'someone :name is in love with',
    'relationship_type_inlovewith_female_with_name' => 'someone :name is in love with',
    'relationship_type_inlovewith_male_with_name' => 'someone :name is in love with',

    'relationship_type_lovedby' => 'loved by',
    'relationship_type_lovedby_female' => 'loved by',
    'relationship_type_lovedby_male' => 'loved by',
    'relationship_type_lovedby_with_name' => ':name’s secret lover',
    'relationship_type_lovedby_female_with_name' => ':name’s secret lover',
    'relationship_type_lovedby_male_with_name' => ':name’s secret lover',

    'relationship_type_ex' => 'bývalý partner',
    'relationship_type_ex_female' => 'bývalá přítelkyně',
    'relationship_type_ex_male' => 'bývalý přítel',
    'relationship_type_ex_with_name' => ':name’s ex-partner',
    'relationship_type_ex_female_with_name' => ':name’s ex-girlfriend',
    'relationship_type_ex_male_with_name' => ':name’s ex-boyfriend',

    'relationship_type_parent' => 'rodič',
    'relationship_type_parent_female' => 'matka',
    'relationship_type_parent_male' => 'otec',
    'relationship_type_parent_with_name' => ':name’s parent',
    'relationship_type_parent_female_with_name' => ':name’s mother',
    'relationship_type_parent_male_with_name' => ':name’s father',

    'relationship_type_child' => 'dítě',
    'relationship_type_child_female' => 'dcera',
    'relationship_type_child_male' => 'syn',
    'relationship_type_child_with_name' => ':name’s child',
    'relationship_type_child_female_with_name' => ':name’s daughter',
    'relationship_type_child_male_with_name' => ':name’s son',

    'relationship_type_stepparent' => 'step-parent',
    'relationship_type_stepparent_female' => 'stepmother',
    'relationship_type_stepparent_male' => 'stepfather',
    'relationship_type_stepparent_with_name' => ':name’s step-parent',
    'relationship_type_stepparent_female_with_name' => ':name’s stepmother',
    'relationship_type_stepparent_male_with_name' => ':name’s stepfather',

    'relationship_type_stepchild' => 'stepchild',
    'relationship_type_stepchild_female' => 'stepdaughter',
    'relationship_type_stepchild_male' => 'stepson',
    'relationship_type_stepchild_with_name' => ':name’s stepchild',
    'relationship_type_stepchild_female_with_name' => ':name’s stepdaughter',
    'relationship_type_stepchild_male_with_name' => ':name’s stepson',

    'relationship_type_sibling' => 'sourozenec',
    'relationship_type_sibling_female' => 'sestra',
    'relationship_type_sibling_male' => 'bratr',
    'relationship_type_sibling_with_name' => ':name’s sibling',
    'relationship_type_sibling_female_with_name' => ':name’s sister',
    'relationship_type_sibling_male_with_name' => ':name’s brother',

    'relationship_type_grandparent' => 'prarodič',
    'relationship_type_grandparent_female' => 'babička',
    'relationship_type_grandparent_male' => 'dědeček',
    'relationship_type_grandparent_with_name' => ':name’s grandparent',
    'relationship_type_grandparent_female_with_name' => ':name’s grandmother',
    'relationship_type_grandparent_male_with_name' => ':name’s grandfather',

    'relationship_type_grandchild' => 'vnouče',
    'relationship_type_grandchild_female' => 'vnučka',
    'relationship_type_grandchild_male' => 'vnuk',
    'relationship_type_grandchild_with_name' => ':name’s grandchild',
    'relationship_type_grandchild_female_with_name' => ':name’s granddauther',
    'relationship_type_grandchild_male_with_name' => ':name’s grandson',

    'relationship_type_uncle' => 'strýc',
    'relationship_type_uncle_female' => 'teta',
    'relationship_type_uncle_male' => 'strýc',
    'relationship_type_uncle_with_name' => ':name’s uncle',
    'relationship_type_uncle_female_with_name' => ':name’s aunt',
    'relationship_type_uncle_male_with_name' => ':name’s uncle',

    'relationship_type_nephew' => 'synovec',
    'relationship_type_nephew_female' => 'neteř',
    'relationship_type_nephew_male' => 'synovec',
    'relationship_type_nephew_with_name' => ':name’s nephew',
    'relationship_type_nephew_female_with_name' => ':name’s niece',
    'relationship_type_nephew_male_with_name' => ':name’s nephew',

    'relationship_type_cousin' => 'bratranec',
    'relationship_type_cousin_female' => 'sestřenice',
    'relationship_type_cousin_male' => 'bratranec',
    'relationship_type_cousin_with_name' => ':name’s cousin',
    'relationship_type_cousin_female_with_name' => ':name’s cousin',
    'relationship_type_cousin_male_with_name' => ':name’s cousin',

    'relationship_type_godfather' => 'godparent',
    'relationship_type_godfather_female' => 'kmotra',
    'relationship_type_godfather_male' => 'kmotr',
    'relationship_type_godfather_with_name' => ':name’s godparent',
    'relationship_type_godfather_female_with_name' => ':name’s godmother',
    'relationship_type_godfather_male_with_name' => ':name’s godfather',

    'relationship_type_godson' => 'godchild',
    'relationship_type_godson_female' => 'goddaughter',
    'relationship_type_godson_male' => 'godson',
    'relationship_type_godson_with_name' => ':name’s godchild',
    'relationship_type_godson_female_with_name' => ':name’s goddaughter',
    'relationship_type_godson_male_with_name' => ':name’s godson',

    'relationship_type_friend' => 'kamarád',
    'relationship_type_friend_female' => 'kamarádka',
    'relationship_type_friend_male' => 'přítel',
    'relationship_type_friend_with_name' => ':name’s friend',
    'relationship_type_friend_female_with_name' => ':name’s friend',
    'relationship_type_friend_male_with_name' => ':name’s friend',

    'relationship_type_bestfriend' => 'nejlepší kamarád',
    'relationship_type_bestfriend_female' => 'nejlepší kamarádka',
    'relationship_type_bestfriend_male' => 'nejlepší přítel',
    'relationship_type_bestfriend_with_name' => ':name’s best friend',
    'relationship_type_bestfriend_female_with_name' => ':name’s best friend',
    'relationship_type_bestfriend_male_with_name' => ':name’s best friend',

    'relationship_type_colleague' => 'kolega',
    'relationship_type_colleague_female' => 'kolegyně',
    'relationship_type_colleague_male' => 'colleague',
    'relationship_type_colleague_with_name' => ':name’s colleague',
    'relationship_type_colleague_female_with_name' => ':name’s colleague',
    'relationship_type_colleague_male_with_name' => ':name’s colleague',

    'relationship_type_boss' => 'nadřízený',
    'relationship_type_boss_female' => 'nadřízená',
    'relationship_type_boss_male' => 'boss',
    'relationship_type_boss_with_name' => ':name’s boss',
    'relationship_type_boss_female_with_name' => ':name’s boss',
    'relationship_type_boss_male_with_name' => ':name’s boss',

    'relationship_type_subordinate' => 'podřízený',
    'relationship_type_subordinate_female' => 'podřízená',
    'relationship_type_subordinate_male' => 'subordinate',
    'relationship_type_subordinate_with_name' => ':name’s subordinate',
    'relationship_type_subordinate_female_with_name' => ':name’s subordinate',
    'relationship_type_subordinate_male_with_name' => ':name’s subordinate',

    'relationship_type_mentor' => 'mentor',
    'relationship_type_mentor_female' => 'mentor',
    'relationship_type_mentor_male' => 'mentor',
    'relationship_type_mentor_with_name' => ':name’s mentor',
    'relationship_type_mentor_female_with_name' => ':name’s mentor',
    'relationship_type_mentor_male_with_name' => ':name’s mentor',

    'relationship_type_protege' => 'protégé',
    'relationship_type_protege_female' => 'protégé',
    'relationship_type_protege_male' => 'protégé',
    'relationship_type_protege_with_name' => ':name’s protégé',
    'relationship_type_protege_female_with_name' => ':name’s protégé',
    'relationship_type_protege_male_with_name' => ':name’s protégé',

    'relationship_type_ex_husband' => 'bývalý manžel/ka',
    'relationship_type_ex_husband_female' => 'ex wife',
    'relationship_type_ex_husband_male' => 'bývalý manžel',
    'relationship_type_ex_husband_with_name' => ':name’s ex-spouse',
    'relationship_type_ex_husband_female_with_name' => ':name’s ex wife',
    'relationship_type_ex_husband_male_with_name' => ':name’s ex-husband',

    // emotions
    'emotion_primary_love' => 'Láska',
    'emotion_primary_joy' => 'Radost',
    'emotion_primary_surprise' => 'Překvapení',
    'emotion_primary_anger' => 'Hněv',
    'emotion_primary_sadness' => 'Smutek',
    'emotion_primary_fear' => 'Strach',

    'emotion_secondary_affection' => 'Náklonnost',
    'emotion_secondary_lust' => 'Lust',
    'emotion_secondary_longing' => 'Longing',
    'emotion_secondary_cheerfulness' => 'Cheerfulness',
    'emotion_secondary_zest' => 'Zest',
    'emotion_secondary_contentment' => 'Contentment',
    'emotion_secondary_pride' => 'Hrdost',
    'emotion_secondary_optimism' => 'Optimismus',
    'emotion_secondary_enthrallment' => 'Enthrallment',
    'emotion_secondary_relief' => 'Úleva',
    'emotion_secondary_surprise' => 'Překvapení',
    'emotion_secondary_irritation' => 'Podrážděnost',
    'emotion_secondary_exasperation' => 'Exasperation',
    'emotion_secondary_rage' => 'Vztek',
    'emotion_secondary_disgust' => 'Znechucení',
    'emotion_secondary_envy' => 'Envy',
    'emotion_secondary_suffering' => 'Suffering',
    'emotion_secondary_sadness' => 'Smutek',
    'emotion_secondary_disappointment' => 'Zklamání',
    'emotion_secondary_shame' => 'Shame',
    'emotion_secondary_neglect' => 'Neglect',
    'emotion_secondary_sympathy' => 'Sympatie',
    'emotion_secondary_horror' => 'Horror',
    'emotion_secondary_nervousness' => 'Nervozita',

    'emotion_adoration' => 'Adoration',
    'emotion_affection' => 'Náklonnost',
    'emotion_love' => 'Láska',
    'emotion_fondness' => 'Fondness',
    'emotion_liking' => 'Liking',
    'emotion_attraction' => 'Attraction',
    'emotion_caring' => 'Caring',
    'emotion_tenderness' => 'Tenderness',
    'emotion_compassion' => 'Compassion',
    'emotion_sentimentality' => 'Sentimentality',
    'emotion_arousal' => 'Arousal',
    'emotion_desire' => 'Desire',
    'emotion_lust' => 'Lust',
    'emotion_passion' => 'Passion',
    'emotion_infatuation' => 'Infatuation',
    'emotion_longing' => 'Longing',
    'emotion_amusement' => 'Amusement',
    'emotion_bliss' => 'Bliss',
    'emotion_cheerfulness' => 'Cheerfulness',
    'emotion_gaiety' => 'Gaiety',
    'emotion_glee' => 'Glee',
    'emotion_jolliness' => 'Jolliness',
    'emotion_joviality' => 'Joviality',
    'emotion_joy' => 'Joy',
    'emotion_delight' => 'Delight',
    'emotion_enjoyment' => 'Enjoyment',
    'emotion_gladness' => 'Gladness',
    'emotion_happiness' => 'Happiness',
    'emotion_jubilation' => 'Jubilation',
    'emotion_elation' => 'Elation',
    'emotion_satisfaction' => 'Satisfaction',
    'emotion_ecstasy' => 'Ecstasy',
    'emotion_euphoria' => 'Euphoria',
    'emotion_enthusiasm' => 'Enthusiasm',
    'emotion_zeal' => 'Zeal',
    'emotion_zest' => 'Zest',
    'emotion_excitement' => 'Excitement',
    'emotion_thrill' => 'Thrill',
    'emotion_exhilaration' => 'Exhilaration',
    'emotion_contentment' => 'Contentment',
    'emotion_pleasure' => 'Pleasure',
    'emotion_pride' => 'Pride',
    'emotion_eagerness' => 'Eagerness',
    'emotion_hope' => 'Hope',
    'emotion_optimism' => 'Optimism',
    'emotion_enthrallment' => 'Enthrallment',
    'emotion_rapture' => 'Rapture',
    'emotion_relief' => 'Relief',
    'emotion_amazement' => 'Amazement',
    'emotion_surprise' => 'Surprise',
    'emotion_astonishment' => 'Astonishment',
    'emotion_aggravation' => 'Aggravation',
    'emotion_irritation' => 'Irritation',
    'emotion_agitation' => 'Agitation',
    'emotion_annoyance' => 'Annoyance',
    'emotion_grouchiness' => 'Grouchiness',
    'emotion_grumpiness' => 'Grumpiness',
    'emotion_exasperation' => 'Exasperation',
    'emotion_frustration' => 'Frustration',
    'emotion_anger' => 'Anger',
    'emotion_rage' => 'Rage',
    'emotion_outrage' => 'Outrage',
    'emotion_fury' => 'Fury',
    'emotion_wrath' => 'Wrath',
    'emotion_hostility' => 'Hostility',
    'emotion_ferocity' => 'Ferocity',
    'emotion_bitterness' => 'Bitterness',
    'emotion_hate' => 'Hate',
    'emotion_loathing' => 'Loathing',
    'emotion_scorn' => 'Scorn',
    'emotion_spite' => 'Spite',
    'emotion_vengefulness' => 'Vengefulness',
    'emotion_dislike' => 'Dislike',
    'emotion_resentment' => 'Resentment',
    'emotion_disgust' => 'Disgust',
    'emotion_revulsion' => 'Revulsion',
    'emotion_contempt' => 'Contempt',
    'emotion_envy' => 'Envy',
    'emotion_jealousy' => 'Jealousy',
    'emotion_agony' => 'Agony',
    'emotion_suffering' => 'Suffering',
    'emotion_hurt' => 'Hurt',
    'emotion_anguish' => 'Anguish',
    'emotion_depression' => 'Depression',
    'emotion_despair' => 'Despair',
    'emotion_hopelessness' => 'Hopelessness',
    'emotion_gloom' => 'Gloom',
    'emotion_glumness' => 'Glumness',
    'emotion_sadness' => 'Sadness',
    'emotion_unhappiness' => 'Unhappiness',
    'emotion_grief' => 'Grief',
    'emotion_sorrow' => 'Sorrow',
    'emotion_woe' => 'Woe',
    'emotion_misery' => 'Misery',
    'emotion_melancholy' => 'Melancholy',
    'emotion_dismay' => 'Dismay',
    'emotion_disappointment' => 'Disappointment',
    'emotion_displeasure' => 'Displeasure',
    'emotion_guilt' => 'Guilt',
    'emotion_shame' => 'Shame',
    'emotion_regret' => 'Regret',
    'emotion_remorse' => 'Remorse',
    'emotion_alienation' => 'Alienation',
    'emotion_isolation' => 'Isolation',
    'emotion_neglect' => 'Neglect',
    'emotion_loneliness' => 'Loneliness',
    'emotion_rejection' => 'Rejection',
    'emotion_homesickness' => 'Homesickness',
    'emotion_defeat' => 'Defeat',
    'emotion_dejection' => 'Dejection',
    'emotion_insecurity' => 'Insecurity',
    'emotion_embarrassment' => 'Embarrassment',
    'emotion_humiliation' => 'Humiliation',
    'emotion_insult' => 'Insult',
    'emotion_pity' => 'Pity',
    'emotion_sympathy' => 'Sympathy',
    'emotion_alarm' => 'Alarm',
    'emotion_shock' => 'Shock',
    'emotion_fear' => 'Fear',
    'emotion_fright' => 'Fright',
    'emotion_horror' => 'Horror',
    'emotion_terror' => 'Terror',
    'emotion_panic' => 'Panic',
    'emotion_hysteria' => 'Hysteria',
    'emotion_mortification' => 'Mortification',
    'emotion_anxiety' => 'Anxiety',
    'emotion_nervousness' => 'Nervousness',
    'emotion_tenseness' => 'Tenseness',
    'emotion_uneasiness' => 'Uneasiness',
    'emotion_apprehension' => 'Apprehension',
    'emotion_worry' => 'Worry',
    'emotion_distress' => 'Distress',
    'emotion_dread' => 'Dread',

    // weather
    'weather_sunny' => 'Sunny',
    'weather_clear' => 'Clear',
    'weather_clear-day' => 'Clear',
    'weather_clear-night' => 'Jasná noc',
    'weather_light-drizzle' => 'Slabé mrholení',
    'weather_patchy-light-drizzle' => 'Místy slabé mrholení',
    'weather_patchy-light-rain' => 'Místy slabý déšť',
    'weather_light-rain' => 'Slabý déšť',
    'weather_moderate-rain-at-times' => 'Občasný mírný déšť',
    'weather_moderate-rain' => 'Mírný déšť',
    'weather_patchy-rain-possible' => 'Místy možný déšť',
    'weather_heavy-rain-at-times' => 'Občasný vydatný déšť',
    'weather_heavy-rain' => 'Vydatný déšť',
    'weather_light-freezing-rain' => 'Slabý mrznoucí déšť',
    'weather_moderate-or-heavy-freezing-rain' => 'Střední nebo silný mrznoucí déšť',
    'weather_light-sleet' => 'Slabý déšť se sněhem',
    'weather_moderate-or-heavy-rain-shower' => 'Střední nebo silné déšťové přeháňky',
    'weather_light-rain-shower' => 'Slabé dešťové přeháňky',
    'weather_torrential-rain-shower' => 'Přívalové dešťové přeháňky',
    'weather_rain' => 'Déšť',
    'weather_snow' => 'Sněžení',
    'weather_blowing-snow' => 'Zvířený sníh',
    'weather_patchy-light-snow' => 'Místy slabé sněžení',
    'weather_light-snow' => 'Slabé sněžení',
    'weather_patchy-moderate-snow' => 'Místy střední sněžení',
    'weather_moderate-snow' => 'Mírné sněžení',
    'weather_patchy-heavy-snow' => 'Místy silné sněžení',
    'weather_heavy-snow' => 'Silné sněžení',
    'weather_light-snow-showers' => 'Slabé sněhové přeháňky',
    'weather_moderate-or-heavy-snow-showers' => 'Střední nebo silné sněhové přeháňky',
    'weather_patchy-snow-possible' => 'Místy možné sněžení',
    'weather_patchy-sleet-possible' => 'Místy možný déšť se sněhem',
    'weather_moderate-or-heavy-sleet' => 'Střední nebo silný déšť se sněhem',
    'weather_light-sleet-showers' => 'Slabé přeháňky deště se sněhem',
    'weather_moderate-or-heavy-sleet-showers' => 'Střední nebo silné přeháňky deště se sněhem',
    'weather_sleet' => 'Déšť se sněhem',
    'weather_wind' => 'Vítr',
    'weather_fog' => 'Mlha',
    'weather_freezing-fog' => 'Mrznoucí mlha',
    'weather_mist' => 'Opar',
    'weather_blizzard' => 'Sněhová vánice',
    'weather_overcast' => 'Zataženo',
    'weather_cloudy' => 'Oblačno',
    'weather_partly-cloudy-day' => 'Částečně oblačno',
    'weather_partly-cloudy-night' => 'Částečně oblačno',
    'weather_freezing-drizzle' => 'Mrznoucí mrholení',
    'weather_heavy-freezing-drizzle' => 'Heavy freezing drizzle',
    'weather_patchy-freezing-drizzle-possible' => 'Patchy freezing drizzle possible',
    'weather_ice-pellets' => 'Ice pellets',
    'weather_light-showers-of-ice-pellets' => 'Light showers of ice pellets',
    'weather_moderate-or-heavy-showers-of-ice-pellets' => 'Moderate or heavy showers of ice pellets',
    'weather_thundery-outbreaks-possible' => 'Thundery outbreaks possible',
    'weather_patchy-light-rain-with-thunder' => 'Patchy light rain with thunder',
    'weather_moderate-or-heavy-rain-with-thunder' => 'Moderate or heavy rain with thunder',
    'weather_patchy-light-snow-with-thunder' => 'Patchy light snow with thunder',
    'weather_moderate-or-heavy-snow-with-thunder' => 'Moderate or heavy snow with thunder',
    'weather_current_temperature_celsius' => ':temperature °C',
    'weather_current_temperature_fahrenheit' => ':temperature °F',
    'weather_current_title' => 'Current weather',

    // dav
    'dav_contacts' => 'Contacts',
    'dav_contacts_description' => ':name’s contacts',
    'dav_birthdays' => 'Birthdays',
    'dav_birthdays_description' => ':name’s contact’s birthdays',
    'dav_tasks' => 'Tasks',
    'dav_tasks_description' => ':name’s tasks',

    // contact list
    'contact_list_avatar' => 'Avatar',
    'contact_list_name' => 'Contact',
    'contact_list_description' => 'Description',

];
